==> pogamut-udk-experiments-3.3.1-20120323.120316-1-sources.jar: cz/cuni/amis/pogamut/udk/experiments/IExperimentRunner.java <==
/*
 * Copyright (C) 2011 AMIS research group, Faculty of Mathematics and Physics, Charles University in Prague, Czech Republic
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package cz.cuni.amis.pogamut.udk.experiments;

/**
 * Interface for all classes that may run experiments. 
 * @author Martin Cerny
 */
public interface IExperimentRunner<RESULT, PARAMETERS> {
    /**
     * Called before the first experiment is executed on this runner. Runner should alloccate
     * any neccessarry resources right there
     */
    void prepare();
    
    /**
     * Run a single experiment. Only one experiment may be executed at a given time
     * with a single runner instance, otherwise the behaviour is unspecified.
     * @param experiment
     * @return 
     */
    IExperimentRunResult<RESULT> runExperiment(IExperiment<RESULT, PARAMETERS> experiment);
    
    /**
     * Called after last experiment is executed on this runner. Any resources allocated in {@link #prepare() }
     * should be released here.
     */
    void cleanup();
}

==> pogamut-udk-experiments-3.3.1-20120417.113332-2-sources.jar: cz/cuni/amis/pogamut/udk/experiments/IExperimentRunner.java <==
/*
 * Copyright (C) 2011 AMIS research group, Faculty of Mathematics and Physics, Charles University in Prague, Czech Republic
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package cz.cuni.amis.pogamut.udk.experiments;

/**
 * Interface for all classes that may run experiments. 
 * @author Martin Cerny
 */
public interface IExperimentRunner<RESULT, PARAMETERS> {
    /**
     * Called before the first experiment is executed on this runner. Runner should alloccate
     * any neccessary resources right there
     */
    void prepare();
    
    /**
     * Run a single experiment. Only one experiment may be executed at a given time
     * with a single runner instance, otherwise the behaviour is unspecified.
     * @param experiment
     * @return 
     */
    IExperimentRunResult<RESULT> runExperiment(IExperiment<RESULT, PARAMETERS> experiment);
    
    /**
     * Called after last experiment is executed on this runner. Any resources allocated in {@link #prepare() }
     * should be released here.
     */
    void cleanup();
}
